# Sicbo Dice

[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/sicboDice)](https://www.python.org/)
[![PyPI](https://img.shields.io/pypi/v/sicboDice))](https://pypi.org/project/sicboDice/)
[![GitHub](https://img.shields.io/github/license/defartsa23/shuffle-dice-sicbo)](https://opensource.org/licenses/MIT)

What is sicbo?
-------------
This function will determine the results of shuffling the dice that will be used in the Sicbo game.

## Install

```bash
pip install sicboDice
```

## Quick start

First of all, initialize:

```python
from sicbo import getDice

result = getDice()
```

## Contributing

Questions, comments, bug reports, and pull requests are all welcome.

## License

This software is licensed under the [MIT license](./LICENSE).